'**********************************************************************
'Program: Pulser.bas. Don Owen 20 Feb 2008
'Uses ATMega8515 micro
'**********************************************************************

'**********************************************************************
'** Description                                                      **
'**********************************************************************

'The purpose of this system is to check the range and reliability of a low
'powered radio link.

'System is comprised of the Tx which has a micro driving a Holtek encoder chip
'HC12E which in turn modulates the RF module ZW3100 Tx (433.92MHz). The Rx
'comprises the RF module ZW3102 Rx (433.92MHz) whose demodulated output
'feeds the Holtek decoder chip HC12D which is in turn fed to the micro.
'This document only deals in detail with the Transmit unit.


' This program outputs a pulse from a port. The pulse occurs once every 5 sec
'and lasts for 0.5 sec. A mark/space ratio of 9:1

'The timer workings are as follows
'Times/sec  to overflow (TOV) =Xtal freq/(Pscale * 2^16). If xtal is 10000000
'and Pscale is 1024 then TOV = 0.149. which is 6.71 sec.
'Now the time for each count is 6.71/2^16 = 102.4uSec.

'For a 4.5 sec overflow
'so it will take 4.5/102.4uSec = 43,945 counts to equal 4.5 sec.
'Therefore Preload = MaxCountOfTimer - 43945
'                  = 65536 - 43945
'                  = 21590
'For a 0.5 sec overflow
'so it will take 0.5/102.4uSec = 4883 counts to equal 0.5 sec.
'Therefore Preload = MaxCountOfTimer - 4883
'                  = 65536 - 4883
'                  = 60653


'**********************************************************************
'** Specifications                                                   **
'**********************************************************************



'**********************************************************************
'** Set up data                                                      **
'**********************************************************************

'The Port designations are as follows:

'Port A (PA7 to PA0)

'Port B (PB7 to PB0)

'Port C (PC7 to PC0)

'Port D (PD7 to PD0)

'Port E (PE2 to PE0)

'note : LCD used in PIN mode with 4-bit

$regfile = "m8515.dat"
$crystal = 10000000


'**********************************************************************
'** Set up port data                                                 **
'**********************************************************************
Config Portd = Output

'**********************************************************************
'** Define working variables and constants                           **
'**********************************************************************


'**********************************************************************
'** Actual work starts here.                   .                    **
'**********************************************************************

Config Timer1 = Timer , Prescale = 1024
Timer1 = 21590                               'preload to interupt after 4.5 sec
On Timer1 Timer1_isr
Enable Timer1
Enable Interrupts
Set Portd.7
Start Timer1
Do
Loop




'**********************************************************************
'**                        Define ISR                                **
'**********************************************************************

Timer1_isr:
Stop Timer1
  If Pind.7 = 1 Then
     Goto Set_off_time
    Else
     Goto Set_on_time
  End If
Set_off_time:
Reset Portd.7
Timer1 = 60653                               'preload to interupt after 0.5 sec
Goto Go_again

Set_on_time:
Set Portd.7
Timer1 = 21590                               'preload to interupt after 4.5 sec

Go_again:
Start Timer1

Return








